@@ -34,5 +34,8 @@ class Customer(models.Model):
     )
     lead_reason_other = models.CharField(max_length=50, blank=True)
 
+    has_profile_picture = models.BooleanField(default=False)
+    profile_picture = models.FileField(blank=True)
+
     def __str__(self):
         return self.first_name + " " + self.last_name
